@@ -1,37 +1,10 @@
 #!/usr/bin/python
 
 # coding=utf-8
-
 '''
-redfish-client ::
-
- Usage:
-   redfish-client [options] config add <manager_name> <manager_url> [<login>] [<password>]
-   redfish-client [options] config del <manager_name>
-   redfish-client [options] config modify <manager_name> (manager_name | url | login | password) <changed_value>
-   redfish-client [options] config show
-   redfish-client [options] config showall
-   redfish-client [options] manager getinfo [<manager_name>]
-   redfish-client [options] chassis getinfo [<manager_name>]
-   redfish-client [options] system getinfo [<manager_name>]
-   redfish-client (-h | --help)
-   redfish-client --version
- 
- 
- Options:
-   -h --help            Show this screen.
-   --version            Show version.
-   -c --config FILE     Configuration file
-   -i --inventory FILE  Configuration file [default: $HOME/.redfish/inventory]
-   --insecure           Ignore SSL certificates
-   --debug LEVEL        Run in debug mode, LEVEL from 1 to 3 increase verbosity
-                        Security warning LEVEL > 1 could reveal password into the logs
-   --debugfile FILE     Specify the client debugfile [default: $HOME/.redfish/redfish-client.log]
-   --libdebugfile FILE  Specify python-redfish library log file [default: $HOME/.redfish/python-redfish.log]
- 
- config commands : manage the configuration file.
- manager commands : manage the manager (Light out management). If <manager_name>
-                    is not provided use the 'default' entry
+redfish-client
+This is a client using the python-redfish library to retrieve and perform
+action on redfish compatible systems.
 '''
 from __future__ import unicode_literals
 from __future__ import print_function
@@ -44,7 +17,6 @@ from builtins import object
 import os
 import sys
 import json
-import pprint
 import docopt
 import logging
 import configparser
@@ -290,10 +262,19 @@ if __name__ == '__main__':
     #################################################################
     # Main program
     #################################################################
-    redfishclient_version = "redfish-client PBVER"
+    redfishclient_version = "redfish-client 0.4"
 
     # Parse and manage arguments
-    arguments = docopt.docopt(__doc__, version=redfishclient_version)
+    try:
+        usagefp = '/usr/share/redfish-client' + "/redfish-client_usage.txt"
+        with open(usagefp) as usagefile:
+            usage = usagefile.read()
+            usagefile.close()
+    except (ValueError, IOError):
+        print("Usage file {} cannot be found.".format(usagefp))
+        sys.exit(1)
+
+    arguments = docopt.docopt(usage, version=redfishclient_version)
 
     # Check debuging options
     # Debugging LEVEL :
@@ -349,7 +330,7 @@ if __name__ == '__main__':
     # Load config
     config = configparser.ConfigParser(allow_no_value=True)
     logger.debug("Read configuration file")
-    configfile = 'PBCONFFILE'
+    configfile = '/etc/redfish-client.conf'
 
     if(arguments['--config']):
         configfile = arguments['--config']
